<?php
/**
 * Custom icons for this theme.
 *
 * @package WordPress
 * @subpackage Neatly
 * @since 0.4.8
 */

if ( ! class_exists( 'Neatly_SVG_Icons' ) ) {
	/**
	 * SVG ICONS CLASS
	 * Retrieve the SVG code for the specified icon. Based on a solution in Neatly.
	 */
	class Neatly_SVG_Icons {
		/**
		 * GET SVG CODE
		 * Get the SVG code for the specified icon
		 *
		 * @param string $icon Icon name.
		 * @param string $group Icon group.
		 * @param string $color Color.
		 */
		public static function get_svg( $icon, $group = 'ui', $color = '#1A1A1B' ) {
			if ( 'ui' === $group ) {
				$arr = self::$ui_icons;
			} elseif ( 'social' === $group ) {
				$arr = self::$social_icons;
			} else {
				$arr = array();
			}
			if ( array_key_exists( $icon, $arr ) ) {
				$repl = '<svg class="svg-icon" aria-hidden="true" role="img" focusable="false" ';
				$svg  = preg_replace( '/^<svg /', $repl, trim( $arr[ $icon ] ) ); // Add extra attributes to SVG code.
				if( '' !== $color){
				   $svg  = str_replace( 'path ', 'path fill="'.$color.'" ', $svg ); // Replace the color.
				}else{
				   $svg  = str_replace( 'path ', 'path class="svg_icon" ', $svg ); // Replace the color.
				}

				//$svg  = str_replace( '#', '%23', $svg ); // Urlencode hashes.
				$svg  = preg_replace( "/([\n\t]+)/", ' ', $svg ); // Remove newlines & tabs.
				$svg  = preg_replace( '/>\s*</', '><', $svg ); // Remove white space between SVG tags.
				return $svg;
			}
			return null;
		}

		/**
		 * GET SOCIAL LINK SVG
		 * Detects the social network from a URL and returns the SVG code for its icon.
		 *
		 * @param string $uri The URL to retrieve SVG for.
		 */
		public static function get_social_link_svg( $uri ) {
			static $regex_map; // Only compute regex map once, for performance.
			if ( ! isset( $regex_map ) ) {
				$regex_map = array();
				$map       = &self::$social_icons_map; // Use reference instead of copy, to save memory.
				foreach ( array_keys( self::$social_icons ) as $icon ) {
					$domains            = array_key_exists( $icon, $map ) ? $map[ $icon ] : array( sprintf( '%s.com', $icon ) );
					$domains            = array_map( 'trim', $domains ); // Remove leading/trailing spaces, to prevent regex from failing to match.
					$domains            = array_map( 'preg_quote', $domains );
					$regex_map[ $icon ] = sprintf( '/(%s)/i', implode( '|', $domains ) );
				}
			}
			foreach ( $regex_map as $icon => $regex ) {
				if ( preg_match( $regex, $uri ) ) {
					return neatly_get_theme_svg( $icon, 'social' );
				}
			}
			return null;
		}

		/**
		 * ICON STORAGE
		 * Store the code for all SVGs in an array.
		 *
		 * @var array
		 */
		public static $ui_icons = array(

			'angle-double-right'              => '<svg xmlns="http://www.w3.org/2000/svg" x="0px" y="0px" width="24" height="24" viewBox="0 0 24 24"><path d="M14.5,12c0,0.2-0.1,0.4-0.2,0.6L2.6,23.8C2.5,23.9,2.3,24,2.1,24s-0.4-0.1-0.6-0.2l-1.2-1.2C0.1,22.4,0,22.2,0,22 s0.1-0.4,0.2-0.6L10,12L0.2,2.5C0.1,2.4,0,2.2,0,2s0.1-0.4,0.2-0.6l1.2-1.2C1.6,0.1,1.9,0,2.1,0s0.4,0.1,0.6,0.2l11.6,11.2 C14.4,11.6,14.5,11.8,14.5,12z M24,12c0,0.2-0.1,0.4-0.2,0.6L12.2,23.8C12,23.9,11.8,24,11.6,24c-0.2,0-0.4-0.1-0.6-0.2l-1.2-1.2 c-0.1-0.1-0.2-0.4-0.2-0.6s0.1-0.4,0.2-0.6l9.8-9.5L9.8,2.5C9.6,2.4,9.5,2.2,9.5,2s0.1-0.4,0.2-0.6L11,0.2C11.2,0.1,11.4,0,11.6,0 c0.2,0,0.4,0.1,0.6,0.2l11.6,11.2C23.9,11.6,24,11.8,24,12z"/></svg>',
			'calendar'              => '<svg xmlns="http://www.w3.org/2000/svg" x="0px" y="0px" width="24" height="24" viewBox="0 0 24 24"><path d="M2.6,22.3h3.9v-3.9H2.6V22.3z M7.3,22.3h4.3v-3.9H7.3V22.3z M2.6,17.6h3.9v-4.3H2.6V17.6z M7.3,17.6h4.3v-4.3H7.3V17.6z M2.6,12.4h3.9V8.6H2.6V12.4z M12.4,22.3h4.3v-3.9h-4.3V22.3z M7.3,12.4h4.3V8.6H7.3V12.4z M17.6,22.3h3.9v-3.9h-3.9V22.3z M12.4,17.6h4.3v-4.3h-4.3V17.6z M7.7,6V2.1c0-0.2-0.2-0.4-0.4-0.4H6.4C6.2,1.7,6,1.9,6,2.1V6c0,0.2,0.2,0.4,0.4,0.4h0.9 C7.5,6.4,7.7,6.2,7.7,6z M17.6,17.6h3.9v-4.3h-3.9V17.6z M12.4,12.4h4.3V8.6h-4.3V12.4z M17.6,12.4h3.9V8.6h-3.9V12.4z M18,6V2.1 c0-0.2-0.2-0.4-0.4-0.4h-0.9c-0.2,0-0.4,0.2-0.4,0.4V6c0,0.2,0.2,0.4,0.4,0.4h0.9C17.8,6.4,18,6.2,18,6z M23.1,5.1v17.1 c0,0.9-0.8,1.7-1.7,1.7H2.6c-0.9,0-1.7-0.8-1.7-1.7V5.1c0-0.9,0.8-1.7,1.7-1.7h1.7V2.1C4.3,1,5.3,0,6.4,0h0.9c1.2,0,2.1,1,2.1,2.1 v1.3h5.1V2.1c0-1.2,1-2.1,2.1-2.1h0.9c1.2,0,2.1,1,2.1,2.1v1.3h1.7C22.4,3.4,23.1,4.2,23.1,5.1z"></path></svg>',

			'caret-right'              => '<svg xmlns="http://www.w3.org/2000/svg" x="0px" y="0px" width="24" height="24" viewBox="0 0 24 24"><path d="M18.8,12c0,0.4-0.2,0.8-0.4,1.1L7.8,23.6C7.5,23.8,7.1,24,6.8,24c-0.8,0-1.5-0.7-1.5-1.5v-21C5.3,0.7,5.9,0,6.8,0 c0.4,0,0.8,0.2,1.1,0.4l10.5,10.5C18.6,11.2,18.8,11.6,18.8,12z"/></svg>',

			'caret-down'              => '<svg xmlns="http://www.w3.org/2000/svg" x="0px" y="0px" width="24" height="24" viewBox="0 0 24 24"><path d="M24,6.8c0,0.4-0.2,0.8-0.4,1.1L13.1,18.3c-0.3,0.3-0.7,0.4-1.1,0.4s-0.8-0.2-1.1-0.4L0.4,7.8C0.2,7.5,0,7.1,0,6.8 c0-0.8,0.7-1.5,1.5-1.5h21C23.3,5.3,24,5.9,24,6.8z"/></svg>',

			'chain'              => '<svg xmlns="http://www.w3.org/2000/svg" x="0px" y="0px" width="24" height="24" viewBox="0 0 24 24"><path d="M21.2,17.6c0-0.4-0.1-0.7-0.4-1l-3.1-3.1c-0.3-0.3-0.6-0.4-1-0.4c-0.4,0-0.8,0.2-1.1,0.5c0.5,0.5,1.1,0.9,1.1,1.6 c0,0.8-0.6,1.4-1.4,1.4c-0.8,0-1.2-0.6-1.6-1.1c-0.3,0.3-0.5,0.6-0.5,1.1c0,0.4,0.1,0.7,0.4,1l3,3c0.3,0.3,0.6,0.4,1,0.4 s0.7-0.1,1-0.4l2.2-2.1C21,18.4,21.2,18,21.2,17.6z M10.8,7.3c0-0.4-0.1-0.7-0.4-1l-3-3C7.1,3,6.8,2.8,6.4,2.8C6,2.8,5.7,3,5.4,3.2 L3.2,5.4C3,5.6,2.8,6,2.8,6.4c0,0.4,0.1,0.7,0.4,1l3.1,3.1c0.3,0.3,0.6,0.4,1,0.4c0.4,0,0.8-0.1,1.1-0.5C7.9,9.9,7.3,9.5,7.3,8.7	c0-0.8,0.6-1.4,1.4-1.4c0.8,0,1.2,0.6,1.6,1.1C10.7,8.1,10.8,7.7,10.8,7.3z M24,17.6c0,1.1-0.5,2.2-1.3,3l-2.2,2.1 c-0.8,0.8-1.9,1.2-3,1.2c-1.1,0-2.2-0.4-3-1.3l-3-3c-0.8-0.8-1.2-1.9-1.2-3c0-1.2,0.5-2.3,1.3-3.1l-1.3-1.3 c-0.8,0.8-1.9,1.3-3.1,1.3c-1.1,0-2.2-0.4-3-1.2L1.2,9.4C0.4,8.5,0,7.5,0,6.4c0-1.1,0.5-2.2,1.3-3l2.2-2.1C4.2,0.4,5.3,0,6.4,0 c1.1,0,2.2,0.4,3,1.3l3,3c0.8,0.8,1.2,1.9,1.2,3c0,1.2-0.5,2.3-1.3,3.1l1.3,1.3c0.8-0.8,1.9-1.3,3.1-1.3c1.1,0,2.2,0.4,3,1.2 l3.1,3.1C23.6,15.5,24,16.5,24,17.6z"/></svg>',
			'chevron-left'              => '<svg xmlns="http://www.w3.org/2000/svg" x="0px" y="0px" width="24" height="24" viewBox="0 0 24 24"><path d="M19.7,4.1L11.5,12l8.2,7.9c0.4,0.4,0.4,1,0,1.3l-2.6,2.5c-0.4,0.4-1,0.4-1.4,0L4.3,12.7c-0.4-0.4-0.4-1,0-1.3L15.8,0.3 c0.4-0.4,1-0.4,1.4,0l2.6,2.5C20.1,3.1,20.1,3.7,19.7,4.1z"/></svg>',
			'chevron-right'              => '<svg xmlns="http://www.w3.org/2000/svg" x="0px" y="0px" width="24" height="24" viewBox="0 0 24 24"><path d="M19.7,12.7L8.2,23.7c-0.4,0.4-1,0.4-1.4,0l-2.6-2.5c-0.4-0.4-0.4-1,0-1.3l8.2-7.9L4.3,4.1c-0.4-0.4-0.4-1,0-1.3l2.6-2.5 c0.4-0.4,1-0.4,1.4,0l11.5,11.1C20.1,11.7,20.1,12.3,19.7,12.7z"/></svg>',
			'close'              => '<svg xmlns="http://www.w3.org/2000/svg" x="0px" y="0px" width="24" height="24" viewBox="0 0 24 24"><path d="M24,19.3c0,0.5-0.2,1-0.6,1.4l-2.7,2.7c-0.4,0.4-0.9,0.6-1.4,0.6s-1-0.2-1.4-0.6L12,17.5l-5.9,5.9C5.7,23.8,5.2,24,4.7,24 s-1-0.2-1.4-0.6l-2.7-2.7C0.2,20.3,0,19.8,0,19.3s0.2-1,0.6-1.4L6.5,12L0.6,6.1C0.2,5.7,0,5.2,0,4.7s0.2-1,0.6-1.4l2.7-2.7 C3.7,0.2,4.2,0,4.7,0s1,0.2,1.4,0.6L12,6.5l5.9-5.9C18.3,0.2,18.8,0,19.3,0s1,0.2,1.4,0.6l2.7,2.7C23.8,3.7,24,4.2,24,4.7 s-0.2,1-0.6,1.4L17.5,12l5.9,5.9C23.8,18.3,24,18.8,24,19.3z"/></svg>',

			'comment-o'              => '<svg xmlns="http://www.w3.org/2000/svg" x="0px" y="0px" width="24" height="24" viewBox="0 0 24 24"><path d="M12,3.4c-5.6,0-10.3,3.1-10.3,6.9c0,2,1.3,3.9,3.7,5.2l1.2,0.7l-0.4,1.3c-0.3,1-0.6,1.7-0.9,2.3c1.4-0.6,2.6-1.3,3.7-2.3 L9.5,17l0.8,0.1c0.6,0.1,1.2,0.1,1.7,0.1c5.6,0,10.3-3.1,10.3-6.9S17.6,3.4,12,3.4z M24,10.3c0,4.7-5.4,8.6-12,8.6 c-0.7,0-1.3,0-1.9-0.1c-1.8,1.6-3.8,2.7-6.2,3.2c-0.5,0.1-1,0.2-1.5,0.3H2.3c-0.3,0-0.5-0.2-0.6-0.5v0c-0.1-0.3,0.2-0.5,0.4-0.8 c0.8-1,1.8-1.8,2.4-4C1.8,15.4,0,13,0,10.3c0-4.7,5.4-8.6,12-8.6l0,0C18.6,1.7,24,5.5,24,10.3z"/></svg>',

			'comments-o'              => '<svg xmlns="http://www.w3.org/2000/svg" x="0px" y="0px" width="24" height="24" viewBox="0 0 24 24"><path d="M9.4,4.3c-4.2,0-7.7,2.4-7.7,5.1c0,1.5,1,2.9,2.7,3.9l1.3,0.8l-0.5,1.1c0.3-0.2,0.6-0.3,0.8-0.5l0.6-0.4l0.7,0.1 c0.7,0.1,1.4,0.2,2,0.2c4.2,0,7.7-2.4,7.7-5.1S13.6,4.3,9.4,4.3z M9.4,2.6c5.2,0,9.4,3.1,9.4,6.9s-4.2,6.9-9.4,6.9 c-0.8,0-1.6-0.1-2.4-0.2c-1.1,0.8-2.4,1.4-3.7,1.7C3,17.9,2.6,17.9,2.2,18h0c-0.2,0-0.4-0.2-0.4-0.4l0,0C1.7,17.4,1.8,17.2,2,17 c0.5-0.6,1.1-1.1,1.6-2.2C1.4,13.5,0,11.6,0,9.4C0,5.6,4.2,2.6,9.4,2.6z M20.4,18.2c0.5,1.1,1,1.6,1.6,2.2c0.1,0.2,0.3,0.3,0.3,0.6 l0,0c-0.1,0.2-0.3,0.4-0.5,0.4c-0.4-0.1-0.8-0.1-1.2-0.2c-1.4-0.3-2.6-0.9-3.7-1.7c-0.8,0.1-1.5,0.2-2.4,0.2c-2.4,0-4.6-0.7-6.3-1.8	C8.6,18,9,18,9.4,18c2.9,0,5.6-0.8,7.7-2.3c2.2-1.6,3.5-3.8,3.5-6.2c0-0.7-0.1-1.4-0.3-2c2.3,1.2,3.7,3.2,3.7,5.5 C24,15,22.6,17,20.4,18.2z"/></svg>',

			'file-text-o'          => '<svg xmlns="http://www.w3.org/2000/svg" x="0px" y="0px" width="24" height="24" viewBox="0 0 24 24"><path d="M21.4,5.1c0.5,0.5,0.9,1.5,0.9,2.2v15.4c0,0.7-0.6,1.3-1.3,1.3H3c-0.7,0-1.3-0.6-1.3-1.3V1.3C1.7,0.6,2.3,0,3,0h12	c0.7,0,1.7,0.4,2.2,0.9L21.4,5.1z M15.4,1.8v5h5c-0.1-0.2-0.2-0.5-0.3-0.5L16,2.1C15.9,2,15.7,1.9,15.4,1.8z M20.6,22.3V8.6H15 c-0.7,0-1.3-0.6-1.3-1.3V1.7H3.4v20.6H20.6z M6.9,10.7c0-0.2,0.2-0.4,0.4-0.4h9.4c0.2,0,0.4,0.2,0.4,0.4v0.9c0,0.2-0.2,0.4-0.4,0.4 H7.3c-0.2,0-0.4-0.2-0.4-0.4V10.7z M16.7,13.7c0.2,0,0.4,0.2,0.4,0.4V15c0,0.2-0.2,0.4-0.4,0.4H7.3c-0.2,0-0.4-0.2-0.4-0.4v-0.9 c0-0.2,0.2-0.4,0.4-0.4H16.7z M16.7,17.1c0.2,0,0.4,0.2,0.4,0.4v0.9c0,0.2-0.2,0.4-0.4,0.4H7.3c-0.2,0-0.4-0.2-0.4-0.4v-0.9 c0-0.2,0.2-0.4,0.4-0.4H16.7z"/></svg>',

			'folder-open-o'          => '<svg xmlns="http://www.w3.org/2000/svg" x="0px" y="0px" width="24" height="24" viewBox="0 0 24 24"><path d="M22.4,13.2c0-0.4-0.4-0.4-0.7-0.4H8c-0.7,0-1.5,0.4-2,0.9l-3.7,4.4c-0.1,0.2-0.2,0.3-0.2,0.5c0,0.4,0.4,0.4,0.7,0.4h13.7 c0.7,0,1.5-0.4,2-0.9l3.7-4.4C22.3,13.5,22.4,13.3,22.4,13.2z M8,11.2h9.7V9.3c0-0.7-0.5-1.2-1.2-1.2H9.3C8.6,8.1,8,7.6,8,7V6.2 C8,5.5,7.5,5,6.8,5h-4C2.1,5,1.6,5.5,1.6,6.2v10.3l3.2-3.9C5.6,11.8,6.9,11.2,8,11.2z M24,13.2c0,0.6-0.2,1.1-0.6,1.4L19.7,19 c-0.7,0.9-2.1,1.4-3.2,1.4H2.8C1.3,20.6,0,19.3,0,17.8V6.2c0-1.4,1.3-2.7,2.8-2.7h4c1.5,0,2.8,1.3,2.8,2.7v0.4h6.8 c1.5,0,2.8,1.3,2.8,2.7v1.9h2.4c0.9,0,1.7,0.4,2.1,1.2C23.9,12.7,24,12.9,24,13.2z"/></svg>',

			'home'          => '<svg xmlns="http://www.w3.org/2000/svg" x="0px" y="0px" width="24" height="24" viewBox="0 0 24 24"><path d="M20.6,13.5v7.1c0,0.5-0.4,1-1,1h-5.7v-5.7h-3.8v5.7H4.4c-0.5,0-1-0.4-1-1v-7.1c0,0,0-0.1,0-0.1L12,6.3L20.6,13.5 C20.6,13.4,20.6,13.4,20.6,13.5z M23.9,12.4L23,13.5c-0.1,0.1-0.2,0.1-0.3,0.2h0c-0.1,0-0.2,0-0.3-0.1L12,5L1.7,13.6 c-0.1,0.1-0.2,0.1-0.4,0.1c-0.1,0-0.2-0.1-0.3-0.2l-0.9-1.1c-0.2-0.2-0.1-0.5,0.1-0.7l10.7-8.9c0.6-0.5,1.6-0.5,2.3,0l3.6,3V3 c0-0.3,0.2-0.5,0.5-0.5h2.9c0.3,0,0.5,0.2,0.5,0.5V9l3.3,2.7C24,11.9,24.1,12.2,23.9,12.4z"/></svg>',

			'menu'              => '<svg xmlns="http://www.w3.org/2000/svg" x="0px" y="0px" width="24" height="24" viewBox="0 0 24 24"><path d="M24,20L24,20c0,1.1-0.9,2-2,2H2c-1.1,0-2-0.9-2-2v0c0-1.1,0.9-2,2-2h20C23.1,18,24,18.9,24,20z M24,12L24,12 c0,1.1-0.9,2-2,2H2c-1.1,0-2-0.9-2-2v0c0-1.1,0.9-2,2-2h20C23.1,10,24,10.9,24,12z M24,4L24,4c0,1.1-0.9,2-2,2H2C0.9,6,0,5.1,0,4v0 c0-1.1,0.9-2,2-2h20C23.1,2,24,2.9,24,4z"/></svg>',

			'pencil'              => '<svg xmlns="http://www.w3.org/2000/svg" x="0px" y="0px" width="24" height="24" viewBox="0 0 24 24"><path d="M5.8,22l1.4-1.4l-3.7-3.7L2,18.2v1.7h2v2H5.8z M14,7.3c0-0.2-0.1-0.3-0.3-0.3c-0.1,0-0.2,0-0.3,0.1l-8.6,8.6 c-0.1,0.1-0.1,0.2-0.1,0.3c0,0.2,0.1,0.3,0.3,0.3c0.1,0,0.2,0,0.3-0.1l8.6-8.6C14,7.5,14,7.4,14,7.3z M13.2,4.2l6.6,6.6L6.6,24H0 v-6.6L13.2,4.2z M24,5.8c0,0.5-0.2,1.1-0.6,1.4l-2.6,2.6l-6.6-6.6l2.6-2.6C17.2,0.2,17.7,0,18.2,0c0.5,0,1.1,0.2,1.4,0.6l3.7,3.7 C23.8,4.7,24,5.2,24,5.8z"/></svg>',

			'refresh'              => '<svg xmlns="http://www.w3.org/2000/svg" x="0px" y="0px" width="24" height="24" viewBox="0 0 24 24"><path d="M23.6,14.5c0,0,0,0.1,0,0.1c-1.3,5.5-5.9,9.4-11.7,9.4c-3,0-6-1.2-8.2-3.3l-2,2C1.5,22.9,1.3,23,1,23c-0.5,0-1-0.5-1-1v-7 c0-0.5,0.5-1,1-1h7c0.5,0,1,0.5,1,1c0,0.3-0.1,0.5-0.3,0.7l-2.1,2.1C8,19.2,10,20,12,20c2.8,0,5.4-1.4,6.8-3.8 c0.4-0.6,0.6-1.2,0.8-1.8c0.1-0.2,0.2-0.4,0.5-0.4h3C23.4,14,23.6,14.2,23.6,14.5z M24,2v7c0,0.5-0.5,1-1,1h-7c-0.5,0-1-0.5-1-1 c0-0.3,0.1-0.5,0.3-0.7l2.2-2.2C16,4.8,14,4,12,4C9.2,4,6.6,5.4,5.2,7.8C4.8,8.4,4.6,9,4.4,9.6C4.3,9.9,4.1,10,3.9,10H0.8 c-0.3,0-0.5-0.2-0.5-0.5V9.4C1.6,3.8,6.2,0,12,0c3.1,0,6,1.2,8.3,3.3l2-2C22.5,1.1,22.7,1,23,1C23.5,1,24,1.5,24,2z"/></svg>',

			'reply'              => '<svg xmlns="http://www.w3.org/2000/svg" x="0px" y="0px" width="24" height="24" viewBox="0 0 24 24"><path d="M24,15.4c0,1.9-0.9,4.3-1.7,6c-0.1,0.3-0.3,0.7-0.5,1c-0.1,0.1-0.2,0.2-0.4,0.2c-0.3,0-0.4-0.2-0.4-0.5 c0-0.2,0.1-0.5,0.1-0.7c0-0.5,0.1-1.1,0.1-1.6c0-6.4-3.8-7.5-9.6-7.5h-3v3.4c0,0.5-0.4,0.9-0.9,0.9c-0.2,0-0.4-0.1-0.6-0.3L0.3,9.6 C0.1,9.4,0,9.2,0,9s0.1-0.4,0.3-0.6l6.9-6.9c0.2-0.2,0.4-0.3,0.6-0.3c0.5,0,0.9,0.4,0.9,0.9v3.4h3c4.4,0,9.9,0.8,11.7,5.4 C23.9,12.4,24,13.9,24,15.4z"/></svg>',

			'search'              => '<svg xmlns="http://www.w3.org/2000/svg" x="0px" y="0px" width="24" height="24" viewBox="0 0 24 24"><path d="M16.6,10.2c0-3.6-2.9-6.5-6.5-6.5s-6.5,2.9-6.5,6.5s2.9,6.5,6.5,6.5S16.6,13.7,16.6,10.2z M24,22.2c0,1-0.8,1.8-1.8,1.8 c-0.5,0-1-0.2-1.3-0.5l-4.9-4.9c-1.7,1.2-3.7,1.8-5.8,1.8C4.5,20.3,0,15.8,0,10.2S4.5,0,10.2,0s10.2,4.5,10.2,10.2 c0,2-0.6,4.1-1.8,5.8l4.9,4.9C23.8,21.2,24,21.7,24,22.2z"/></svg>',

			'signal'              => '<svg xmlns="http://www.w3.org/2000/svg" x="0px" y="0px" width="24" height="24" viewBox="0 0 24 24"><path d="M3.4,19.3v2.6c0,0.2-0.2,0.4-0.4,0.4H0.4c-0.2,0-0.4-0.2-0.4-0.4v-2.6c0-0.2,0.2-0.4,0.4-0.4H3C3.2,18.9,3.4,19,3.4,19.3z M8.6,17.6v4.3c0,0.2-0.2,0.4-0.4,0.4H5.6c-0.2,0-0.4-0.2-0.4-0.4v-4.3c0-0.2,0.2-0.4,0.4-0.4h2.6C8.4,17.1,8.6,17.3,8.6,17.6z M13.7,14.1v7.7c0,0.2-0.2,0.4-0.4,0.4h-2.6c-0.2,0-0.4-0.2-0.4-0.4v-7.7c0-0.2,0.2-0.4,0.4-0.4h2.6C13.5,13.7,13.7,13.9,13.7,14.1z M18.9,9v12.9c0,0.2-0.2,0.4-0.4,0.4h-2.6c-0.2,0-0.4-0.2-0.4-0.4V9c0-0.2,0.2-0.4,0.4-0.4h2.6C18.7,8.6,18.9,8.8,18.9,9z M24,2.1 v19.7c0,0.2-0.2,0.4-0.4,0.4H21c-0.2,0-0.4-0.2-0.4-0.4V2.1c0-0.2,0.2-0.4,0.4-0.4h2.6C23.8,1.7,24,1.9,24,2.1z"/></svg>',

			'side-bar'              => '<svg xmlns="http://www.w3.org/2000/svg" x="0px" y="0px" width="24" height="24" viewBox="0 0 24 24"><path d="M23.1,4.5H0.9C0.4,4.5,0,4.1,0,3.7V2.2c0-0.4,0.4-0.7,0.9-0.7h22.3c0.4,0,0.8,0.4,0.8,0.7v1.5C24,4.1,23.6,4.5,23.1,4.5z M23.1,10.5H6.9C6.4,10.5,6,10.1,6,9.7V8.3c0-0.4,0.4-0.8,0.9-0.8h16.3c0.5,0,0.9,0.4,0.9,0.8v1.5C24,10.2,23.6,10.5,23.1,10.5z M23.1,16.5H3.8c-0.5,0-0.8-0.3-0.8-0.8v-1.5c0-0.4,0.4-0.8,0.8-0.8h19.3c0.5,0,0.8,0.3,0.8,0.8v1.5C23.9,16.2,23.5,16.5,23.1,16.5z M23.2,22.5H8.8c-0.5,0-0.8-0.3-0.8-0.8v-1.5c0-0.4,0.4-0.8,0.8-0.8h14.3c0.5,0,0.8,0.3,0.8,0.8v1.5C24,22.2,23.6,22.5,23.2,22.5z"/></svg>',

			'tag'              => '<svg xmlns="http://www.w3.org/2000/svg" x="0px" y="0px" width="24" height="24" viewBox="0 0 24 24"><path d="M7.1,5.1c0-1.1-0.9-2-2-2s-2,0.9-2,2s0.9,2,2,2S7.1,6.2,7.1,5.1z M24,14.2c0,0.5-0.2,1.1-0.6,1.4l-7.8,7.8	c-0.4,0.4-0.9,0.6-1.4,0.6s-1.1-0.2-1.4-0.6L1.4,12.1C0.6,11.3,0,9.7,0,8.6V2c0-1.1,0.9-2,2-2h6.6c1.1,0,2.7,0.6,3.5,1.4l11.3,11.3 C23.8,13.1,24,13.7,24,14.2z"></path></svg>',

			'thumb-tack'              => '<svg xmlns="http://www.w3.org/2000/svg" x="0px" y="0px" width="24" height="24" viewBox="0 0 24 24"><path d="M10.6,10.6V4.2c0-0.3-0.2-0.5-0.5-0.5c-0.3,0-0.5,0.2-0.5,0.5v6.5c0,0.3,0.2,0.5,0.5,0.5C10.4,11.1,10.6,10.9,10.6,10.6z M20.3,15.7c0,0.5-0.4,0.9-0.9,0.9h-6.2l-0.7,7c0,0.2-0.2,0.4-0.4,0.4h0c-0.2,0-0.4-0.2-0.5-0.4l-1.1-7H4.6c-0.5,0-0.9-0.4-0.9-0.9 c0-2.4,1.8-4.6,3.7-4.6V3.7c-1,0-1.8-0.8-1.8-1.8S6.4,0,7.4,0h9.2c1,0,1.8,0.8,1.8,1.8s-0.8,1.8-1.8,1.8v7.4 C18.5,11.1,20.3,13.3,20.3,15.7z"/></svg>',

			'user'              => '<svg xmlns="http://www.w3.org/2000/svg" x="0px" y="0px" width="24" height="24" viewBox="0 0 24 24"><path d="M22,19.9c0,2.3-1.5,4.1-3.3,4.1H5.3C3.5,24,2,22.1,2,19.9C2,15.8,3,11,7.1,11c1.3,1.2,3,2,4.9,2s3.6-0.8,4.9-2 C21,11,22,15.8,22,19.9z M18,6c0,3.3-2.7,6-6,6S6,9.3,6,6s2.7-6,6-6S18,2.7,18,6z"></path></svg>',

		);

		/**
		 * Social Icons – domain mappings.
		 *
		 * By default, each Icon ID is matched against a .com TLD. To override this behavior,
		 * specify all the domains it covers (including the .com TLD too, if applicable).
		 *
		 * @var array
		 */
		public static $social_icons_map = array(
			'amazon'      => array(
				'amazon.com',
				'amazon.cn',
				'amazon.in',
				'amazon.fr',
				'amazon.de',
				'amazon.it',
				'amazon.nl',
				'amazon.es',
				'amazon.co',
				'amazon.ca',
			),
			'apple'       => array(
				'apple.com',
				'itunes.com',
			),
			'behance'     => array(
				'behance.net',
			),
			'codepen'     => array(
				'codepen.io',
			),
			'facebook'    => array(
				'facebook.com',
				'fb.me',
			),
			'feed'        => array(
				'feed',
			),
			'google-plus' => array(
				'plus.google.com',
			),
			'lastfm'      => array(
				'last.fm',
			),
			'mail'        => array(
				'mailto:',
			),
			'slideshare'  => array(
				'slideshare.net',
				'slideshare.com',
			),
			'pocket'      => array(
				'getpocket.com',
			),
			'twitch'      => array(
				'twitch.tv',
			),
			'wordpress'   => array(
				'wordpress.com',
				'wordpress.org',
			),
		);

		/**
		 * Social Icons – svg sources.
		 *
		 * @var array
		 */
		public static $social_icons = array(
			'youtube'     => '<svg xmlns="http://www.w3.org/2000/svg" width="19" height="14" viewBox="0 0 19 14"><path d="M18.216 3.72l.088.905a20.4 20.4 0 01.088 1.977v1.371c0 .739-.029 1.41-.088 2.013l-.088.905-.158.686c-.105.457-.287.826-.545 1.107-.351.352-.7.566-1.046.642-.345.076-.606.12-.782.132-.62.047-1.3.082-2.039.105-.726.024-1.406.041-2.039.053-.633.012-1.16.018-1.582.018H8.636c-.503-.012-1.092-.024-1.766-.036a116.07 116.07 0 01-2.03-.052 27.164 27.164 0 01-1.565-.088c-.2-.035-.495-.085-.888-.15-.392-.064-.764-.272-1.116-.624-.27-.281-.454-.65-.554-1.107l-.149-.686-.088-.905a20.961 20.961 0 01-.088-2.013v-1.37c0-.727.03-1.39.088-1.987l.088-.897.158-.703c.106-.468.287-.832.545-1.09.352-.375.7-.594 1.046-.659.346-.064.607-.102.782-.114a47.09 47.09 0 012.04-.105c.726-.024 1.406-.041 2.038-.053C7.81.983 8.337.977 8.76.977h1.266c.422 0 .95.006 1.582.018.633.012 1.313.03 2.04.053a47.09 47.09 0 012.038.105c.176.023.437.067.782.132.346.064.695.278 1.046.641.27.27.454.636.554 1.1l.15.693zm-6.398 3.726l.598-.316-4.852-2.532v5.063l4.254-2.215z"/></svg>',

		);

	}
}
